package
Version:
v0.0.0-...-93d9ef7
Opens a new window with list of versions in this module.
Published: Nov 16, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Address string `yaml:"address"`
Port string `yaml:"port"`
SupportedLanguages []string `yaml:"supportedLanguages"`
RabbitMQ struct {
URL string `yaml:"url"`
Queue string `yaml:"queue"`
} `yaml:"rabbitmq"`
MaxJobs int `yaml:"maxJobs"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.